@@ -1,5 +1,5 @@
 package Sys::Info::Driver::Linux::OS;
-$Sys::Info::Driver::Linux::OS::VERSION = '0.7909';
+$Sys::Info::Driver::Linux::OS::VERSION = '0.7910';
 use strict;
 use warnings;
 use parent qw( Sys::Info::Base );
@@ -132,8 +132,24 @@ sub login_name {
     my($self, @args) = @_;
     my %opt   = @args % 2 ? () : @args;
     my $login = POSIX::getlogin() || return;
-    my $rv    = eval { $opt{real} ? (getpwnam $login)[REAL_NAME_FIELD] : $login };
-    $rv =~ s{ [,]{3,} \z }{}xms if $opt{real};
+    my $rv;
+    eval {
+        if ( $opt{real} ) {
+            $rv = (getpwnam $login)[REAL_NAME_FIELD];
+            $rv =~ s{ [,]{3,} \z }{}xms;
+            if ( ! $rv ) {
+                # unset, fall back to the loginname
+                $rv = $login;
+                delete $opt{real};
+            }
+        }
+        $rv ||= $login;
+        1;
+    } or do {
+        my $eval_error = $@ || 'Zombie error';
+        warn sprintf 'Error getting login name: %s', $@;
+        $rv = $login;
+    };
     return $rv;
 }
 
@@ -293,7 +309,7 @@ Sys::Info::Driver::Linux::OS
 
 =head1 VERSION
 
-version 0.7909
+version 0.7910
 
 =head1 SYNOPSIS
 
